diff --git src/wp-admin/includes/network.php src/wp-admin/includes/network.php
index 70cb14ea93..fc6072a765 100644
--- src/wp-admin/includes/network.php
+++ src/wp-admin/includes/network.php
@@ -384,6 +384,7 @@ function network_step1( $errors = false ) {
  */
 function network_step2( $errors = false ) {
 	global $wpdb;
+	global $is_nginx;
 
 	$hostname          = get_clean_basedomain();
 	$slashed_home      = trailingslashit( get_option( 'home' ) );
@@ -616,7 +617,19 @@ define('BLOG_ID_CURRENT_SITE', 1);
 	</ol>
 
 		<?php
-	else : // End iis7_supports_permalinks(). Construct an .htaccess file instead:
+       elseif($is_nginx): // end iis7_supports_permalinks(). check if server is nginx and print link to Codex:
+
+       $section = $subdomain_install ? 'wordpress-multisite-subdomains-rules' : 'wordpress-multisite-subdirectory-rules';
+       echo  '<li><p>';
+       printf(
+               __('It seems your network is running with NGINX webserver. Please, visit %1$s to get details about further configuration'),
+              '<a href="https://wordpress.org/support/article/nginx/#'.$section.'" target="_blank">https://wordpress.org/support/article/nginx/#'.$section.'</a>'
+       );
+       echo '</p>'
+               ?>
+	       <?php
+       else : // end of nginx variant, construct .htaccess
+
 
 		$ms_files_rewriting = '';
 		if ( is_multisite() && get_site_option( 'ms_files_rewriting' ) ) {
